Summary: Kernel-based Virtual Machine
Name: kvm
Version: 36
Release: 9%{?dist}
License: GPLv2+, LGPLv2+
Group: Development/Tools
URL: http://kvm.sf.net
Source0: http://download.sourceforge.net/sourceforge/kvm/kvm-%{version}.tar.gz
Source1: kvm.modules
Patch0: kvm-19-defaults.patch
Patch1: kvm-35-ldflags.patch
Patch2: kvm-bootmenu.patch
# patches from upstream qemu
Patch101: kvm-rtl8139-mmio-regions.patch
Patch102: qemu-atapi-hsm.patch
Patch103: qemu-0.9.0-vnc-authentication.patch
Patch104: kvm-rtl8139-checksum.patch
Patch105: kvm-36-pxeboot.patch
Patch106: %{name}-%{version}-block-rw-range-check.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: SDL-devel 
# to build the bios
BuildRequires: dev86
BuildRequires: %{_includedir}/gnu/stubs-32.h
# qemu doesn't build with gcc 4.x
BuildRequires: compat-gcc-34 
BuildRequires: zlib-devel 
BuildRequires: e2fsprogs-devel
# TLS / x509 auth in VNC server
BuildRequires: gnutls-devel
# for the docs
BuildRequires: texi2html
# kvm kernel side is only x86/x86_64 as that's where the hardware is
ExclusiveArch: %{ix86} x86_64
Requires: initscripts >= 8.08-1

%description
KVM (for Kernel-based Virtual Machine) is a full virtualization solution 
for Linux on x86 hardware. 

Using KVM, one can run multiple virtual machines running unmodified Linux 
or Windows images. Each virtual machine has private virtualized hardware: 
a network card, disk, graphics adapter, etc.

%prep
%setup -q
%patch0 -p1 -b .defaults
%patch1 -p1 -b .ldflags
%patch2 -p1 

%patch101 -p1
%patch102 -p0
%patch103 -p1 -b .vnc
%patch104 -p1
%patch105 -p1
%patch106 -p1

%build
./configure --with-patched-kernel --qemu-cc=gcc34 --kerneldir=$(pwd)/kernel --prefix=%{_prefix}
# we need to install the data bits in a different path
sed -i 's/CONFIG_QEMU_SHAREDIR \"\/usr\/share\/qemu\"/CONFIG_QEMU_SHAREDIR \"\/usr\/share\/kvm\"/' qemu/config-host.h
sed -i 's/datadir=\/usr\/share\/qemu/datadir=\/usr\/share\/kvm/' qemu/config-host.mak

# we can't use RPM_OPT_FLAGS for the same reasons as qemu (#208026) for the
# qemu bits.  so let's set it for the other pieces.  this requires some
# manual keeping up of what is in the kvm tree.
sed -i 's/CFLAGS =/CFLAGS +=/' user/Makefile
echo "CFLAGS=$RPM_OPT_FLAGS" >> user/config.mak
make %{?_smp_mflags} 

# build the bios, and fix it's makefile
sed -i 's/gcc -m32/gcc/' bios/Makefile
make bios

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

# we have to have our own copies of the bios/keymaps due to incompat with
# qemu 0.9.  include the man page
mv $RPM_BUILD_ROOT/%{_mandir}/man1/qemu.1* $RPM_BUILD_ROOT/%{_mandir}/man1/qemu-kvm.1
rm -rf $RPM_BUILD_ROOT/%{_mandir}/man*/qemu-img* $RPM_BUILD_ROOT/%{_docdir}
rm -f $RPM_BUILD_ROOT/%{_bindir}/qemu-img
# no shared lib, static libs
rm -fr $RPM_BUILD_ROOT/%{_includedir} $RPM_BUILD_ROOT/%{_libdir}

mv $RPM_BUILD_ROOT/%{_bindir}/qemu* $RPM_BUILD_ROOT/%{_bindir}/qemu-kvm

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules
install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules/kvm.modules

%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%{_bindir}/qemu-kvm
%{_mandir}/man*/*
%{_datadir}/kvm
%{_sysconfdir}/sysconfig/modules/kvm.modules

%changelog
* Wed Feb 27 2008 Daniel P. Berrange <berrange@redhat.com> - 36-9.fc7
- Fix block device checks for extendable disk formats (rhbz #435211)

* Sat Feb 23 2008 Daniel P. Berrange <berrange@redhat.com> - 36-8.fc7
- Fix block device extents check (rhbz #433560)

* Mon Oct 15 2007 Daniel P. Berrange <berrange@redhat.com> - 36-7
- Fixed PXE boot when KVM is enabled (rhbz #331191)

* Wed Sep 26 2007 Daniel P. Berrange <berrange@redhat.com> - 36-6
- Fixed rtl8139 checksum calculation for Vista (rhbz #308201)

* Mon Sep 24 2007 Jeremy Katz <katzj@redhat.com> - 36-5
- fix build on x86_64

* Mon Sep 24 2007 Jeremy Katz <katzj@redhat.com> - 36-3
- add support for selecting boot device at runtime

* Tue Sep  4 2007 Jeremy Katz <katzj@redhat.com> - 36-2
- rebase vnc auth patch

* Tue Sep  4 2007 Jeremy Katz <katzj@redhat.com> - 36-1
- update to kvm-36

* Mon Aug 27 2007 Daniel P. Berrange <berrange@redhat.com> - 35-3
- Added patch for VNC password auth and TLS+x509 cert auth

* Mon Aug 20 2007 Jeremy Katz <katzj@redhat.com> - 35-2
- add fix for ATAPI from upstream qemu

* Mon Aug 20 2007 Jeremy Katz <katzj@redhat.com> - 35-1
- update to kvm-35
- patch to use -Wl,--build-id so that we get debuginfo

* Thu Jul 19 2007 Jeremy Katz <katzj@redhat.com> - 31-1
- update to kvm-31

* Mon Jul 16 2007 Jeremy Katz <katzj@redhat.com> - 28-2
- add patch from danpb to fix mac addrs of multiple 8139 nics (#247641)

* Wed Jun 13 2007 Jeremy Katz <katzj@redhat.com> - 28-1
- update to kvm-28

* Sat Jun  9 2007 Jeremy Katz <katzj@redhat.com> - 27-1
- update to kvm-27

* Tue May 29 2007 Jeremy Katz <katzj@redhat.com> - 26-1
- update to kvm-26

* Wed May 16 2007 Jeremy Katz <katzj@redhat.com> - 24-1
- update to kvm-24

* Wed Apr 25 2007 Jeremy Katz <katzj@redhat.com> - 19-2
- fix kernel and ramdisk being specified on the command line (#237879)

* Tue Apr 17 2007 Jeremy Katz <katzj@redhat.com> - 19-1
- update to kvm-19
- use rtl8139 as the default nic emulation instead of ne2k_pci (#236790)

* Mon Mar 26 2007 Jeremy Katz <katzj@redhat.com> - 15-2
- add file so that kvm modules get loaded on boot

* Wed Mar  7 2007 Jeremy Katz <katzj@redhat.com> - 15-1
- update to kvm-15

* Mon Feb 26 2007 Jeremy Katz <katzj@redhat.com> - 14-2
- use default optflags for non-qemu pieces (#230012)

* Fri Feb 23 2007 Jeremy Katz <katzj@redhat.com> - 14-1
- update to kvm-14
- note: this requires a kernel that's 2.6.21-rc1 or newer

* Mon Feb 19 2007 Jeremy Katz <katzj@redhat.com> - 12-3
- add the buildrequires for the docs to build

* Mon Feb 19 2007 Jeremy Katz <katzj@redhat.com> - 12-2
- include bios and keymaps in the kvm package since we need a slightly 
  different version for kvm now
- include man page

* Fri Jan 26 2007 Jeremy Katz <katzj@redhat.com> - 12-1
- update to kvm-12
- add qemu patch for better ATAPI DMA support (which works with ata_piix)

* Fri Jan 19 2007 Jeremy Katz <katzj@redhat.com> - 11-1
- update to kvm-11

* Fri Jan  5 2007 Jeremy Katz <katzj@redhat.com> - 9-1
- update to kvm-9

* Wed Jan  3 2007 Jeremy Katz <katzj@redhat.com> - 7-4
- actually build without -devel...

* Wed Dec 20 2006 Jeremy Katz <katzj@redhat.com> - 7-3
- remove the -devel subpackage since there's no shared lib upstream yet
- direct download link for source 

* Tue Dec 19 2006 Jeremy Katz <katzj@redhat.com> - 7-2
- BR e2fsprogs-devel

* Tue Dec 19 2006 Jeremy Katz <katzj@redhat.com> - 7-1
- Initial build 

